@@ -33,27 +33,19 @@
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 
-#include <gtk/gtkwidget.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkscale.h>
-#include <gtk/gtkrange.h>
-#include <gtk/gtkhscale.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkalignment.h>
-#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtk.h>
 
 #include <gconf/gconf-client.h>
 
+#include "brasero-misc.h"
+
+#include "burn-debug.h"
+
 #include "brasero-player.h"
 #include "brasero-player-bacon.h"
 #include "brasero-utils.h"
 #include "brasero-metadata.h"
 #include "brasero-io.h"
-#include "burn-debug.h"
 
 G_DEFINE_TYPE (BraseroPlayer, brasero_player, GTK_TYPE_ALIGNMENT);
 
@@ -266,10 +258,10 @@ brasero_player_update_position (BraseroPlayer *player)
 		return;
 
 	adjustment = gtk_range_get_adjustment (GTK_RANGE (player->priv->progress));
-	len_string = brasero_utils_get_time_string (player->priv->end - player->priv->start, FALSE, FALSE);
+	len_string = brasero_units_get_time_string (player->priv->end - player->priv->start, FALSE, FALSE);
 
 	value = gtk_range_get_value (GTK_RANGE (player->priv->progress));
-	pos_string = brasero_utils_get_time_string (value, FALSE, FALSE);
+	pos_string = brasero_units_get_time_string (value, FALSE, FALSE);
 
 	/**
 	 * Translators: this is the position being played in the stream. The 
@@ -924,7 +916,17 @@ brasero_player_metadata_completed (GObject *obj,
 			gtk_widget_set_sensitive (player->priv->progress, FALSE);
 	}
 	else if (mime && !strncmp ("image/", mime, 6)) {
-		brasero_player_image (player);
+		/* Only do that if the image is < 20 M otherwise that's crap
+		 * FIXME: maybe a sort of error message here? or use thumbnail? */
+		if (g_file_info_get_size (info) > 100000000) {
+			brasero_player_no_multimedia_stream (player);
+			g_signal_emit (player,
+				       brasero_player_signals [ERROR_SIGNAL],
+				       0);
+		}
+		else
+			brasero_player_image (player);
+
 		return;
 	}
 	else {
