@@ -24,6 +24,8 @@
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 
+#include "brasero-tags.h"
+
 #include "brasero-video-project.h"
 #include "brasero-file-monitor.h"
 #include "brasero-io.h"
@@ -299,7 +301,7 @@ brasero_video_file_free (BraseroVideoFile *file)
 		g_object_unref (file->snapshot);
 
 	if (file->info)
-		brasero_song_info_free (file->info);
+		brasero_stream_info_free (file->info);
 
 	g_free (file);
 }
@@ -523,7 +525,7 @@ brasero_video_project_set_file_information (BraseroVideoProject *self,
 
 	/* Get the song info */
 	if (!file->info)
-		file->info = g_new0 (BraseroSongInfo, 1);
+		file->info = g_new0 (BraseroStreamInfo, 1);
 
 	if (!file->title_set) {
 		if (file->info->title)
@@ -741,7 +743,7 @@ brasero_video_project_result_cb (GObject *obj,
 BraseroVideoFile *
 brasero_video_project_add_uri (BraseroVideoProject *self,
 			       const gchar *uri,
-			       BraseroSongInfo *info,
+			       BraseroStreamInfo *info,
 			       BraseroVideoFile *sibling,
 			       gint64 start,
 			       gint64 end)
@@ -760,7 +762,7 @@ brasero_video_project_add_uri (BraseroVideoProject *self,
 	file->uri = g_strdup (uri);
 
 	if (info) {
-		file->info = brasero_song_info_copy (info);
+		file->info = brasero_stream_info_copy (info);
 
 		if (info->isrc)
 			file->isrc_set = TRUE;
@@ -772,7 +774,7 @@ brasero_video_project_add_uri (BraseroVideoProject *self,
 			file->composer_set = TRUE;
 	}
 	else
-		file->info = g_new0 (BraseroSongInfo, 1);
+		file->info = g_new0 (BraseroStreamInfo, 1);
 
 	if (start > -1)
 		file->start = start;
@@ -982,51 +984,47 @@ brasero_video_project_get_contents (BraseroVideoProject *self,
 		return NULL;
 
 	for (file = priv->first; file; file = file->next) {
-		BraseroSongInfo *info = NULL;
-		BraseroTrack *track;
+		BraseroTrackStream *track;
 
-		if (file->info) {
-			info = brasero_song_info_copy (file->info);
-
-			if (values_set) {
-				if (!file->title_set) {
-					g_free (info->title);
-					info->title = NULL;
-				}
-				if (!file->artist_set) {
-					g_free (info->artist);
-					info->artist = NULL;
-				}
-				if (!file->composer_set) {
-					g_free (info->composer);
-					info->composer = NULL;
-				}
-				if (!file->isrc_set)
-					info->isrc = 0;
-			}
-		}
-		else
-			info = NULL;
-
-		track = brasero_track_new (BRASERO_TRACK_TYPE_AUDIO);
-		brasero_track_set_audio_source (track,
-						file->uri,
-						BRASERO_AUDIO_FORMAT_UNDEFINED|
-						BRASERO_VIDEO_FORMAT_UNDEFINED);
+		track = brasero_track_stream_new ();
+		brasero_track_stream_set_source (track, file->uri);
+		brasero_track_stream_set_format (track,
+						 BRASERO_AUDIO_FORMAT_UNDEFINED|
+						 BRASERO_VIDEO_FORMAT_UNDEFINED);
 
 		if (!values_set || file->len_set)
-			brasero_track_set_audio_boundaries (track,
-							    file->start,
-							    file->end,
-							    -1);
+			brasero_track_stream_set_boundaries (track,
+							     file->start,
+							     file->end,
+							     -1);
 		else
-			brasero_track_set_audio_boundaries (track,
-							    file->start,
-							    0,
-							    -1);
+			brasero_track_stream_set_boundaries (track,
+							     file->start,
+							     0,
+							     -1);
 
-		brasero_track_set_audio_info (track, info);
-		tracks = g_slist_prepend (tracks, track);
+		if (file->info && values_set) {
+			if (!file->title_set)
+				brasero_track_tag_add_string (BRASERO_TRACK (track),
+							      BRASERO_TRACK_STREAM_TITLE_TAG,
+							      file->info->title);
+
+			if (!file->artist_set)
+				brasero_track_tag_add_string (BRASERO_TRACK (track),
+							      BRASERO_TRACK_STREAM_ARTIST_TAG,
+							      file->info->artist);
+
+			if (!file->composer_set)
+				brasero_track_tag_add_string (BRASERO_TRACK (track),
+							      BRASERO_TRACK_STREAM_COMPOSER_TAG,
+							      file->info->composer);
+			if (!file->isrc_set)
+				brasero_track_tag_add_int (BRASERO_TRACK (track),
+							   BRASERO_TRACK_STREAM_ISRC_TAG,
+							   file->info->isrc);
+		}
+
+		tracks = g_slist_prepend (tracks, BRASERO_TRACK (track));
 	}
 
 	tracks = g_slist_reverse (tracks);
@@ -1053,7 +1051,7 @@ brasero_video_project_finalize (GObject *object)
 	for (iter = priv->first; iter; iter = next) {
 		next = iter->next;
 		g_free (iter->uri);
-		brasero_song_info_free (iter->info);
+		brasero_stream_info_free (iter->info);
 		g_free (iter);
 	}
 
